@@ -143,10 +143,13 @@ double unur_distr_cont_eval_dpdf( double x, const UNUR_DISTR *distribution );
 double unur_distr_cont_eval_cdf( double x, const UNUR_DISTR *distribution );
 int unur_distr_cont_set_logpdf( UNUR_DISTR *distribution, UNUR_FUNCT_CONT *logpdf );
 int unur_distr_cont_set_dlogpdf( UNUR_DISTR *distribution, UNUR_FUNCT_CONT *dlogpdf );
+int unur_distr_cont_set_logcdf( UNUR_DISTR *distribution, UNUR_FUNCT_CONT *logcdf );
 UNUR_FUNCT_CONT *unur_distr_cont_get_logpdf( const UNUR_DISTR *distribution );
 UNUR_FUNCT_CONT *unur_distr_cont_get_dlogpdf( const UNUR_DISTR *distribution );
+UNUR_FUNCT_CONT *unur_distr_cont_get_logcdf( const UNUR_DISTR *distribution );
 double unur_distr_cont_eval_logpdf( double x, const UNUR_DISTR *distribution );
 double unur_distr_cont_eval_dlogpdf( double x, const UNUR_DISTR *distribution );
+double unur_distr_cont_eval_logcdf( double x, const UNUR_DISTR *distribution );
 int unur_distr_cont_set_pdfstr( UNUR_DISTR *distribution, const char *pdfstr );
 int unur_distr_cont_set_cdfstr( UNUR_DISTR *distribution, const char *cdfstr );
 char *unur_distr_cont_get_pdfstr( const UNUR_DISTR *distribution );
@@ -159,6 +162,8 @@ int unur_distr_cont_get_pdfparams_vec( const UNUR_DISTR *distribution, int par,
 int unur_distr_cont_set_logpdfstr( UNUR_DISTR *distribution, const char *logpdfstr );
 char *unur_distr_cont_get_logpdfstr( const UNUR_DISTR *distribution );
 char *unur_distr_cont_get_dlogpdfstr( const UNUR_DISTR *distribution );
+int unur_distr_cont_set_logcdfstr( UNUR_DISTR *distribution, const char *logcdfstr );
+char *unur_distr_cont_get_logcdfstr( const UNUR_DISTR *distribution );
 int unur_distr_cont_set_domain( UNUR_DISTR *distribution, double left, double right );
 int unur_distr_cont_get_domain( const UNUR_DISTR *distribution, double *left, double *right );
 int unur_distr_cont_get_truncated( const UNUR_DISTR *distribution, double *left, double *right );
